#!/usr/bin/env bash

YES_FLAG='';

USER_ID=$(id -u)
if [[ "${USER_ID}" != "0" ]]; then
  echo "Running under root user is required"
  exit 1
fi

function printHelp() {
  cat <<'HELP'
This script removes the WP Guardian agent.
Use the "-y" option to force removal without confirmation.
HELP
  exit 1
}

parse_args() {
  while [ "$#" -gt 0 ]; do
    case "$1" in
    -y)
      YES_FLAG="-y"
      break
      ;;
    -h)
      printHelp
      break
      ;;
    --help)
      printHelp
      break
      ;;
    *)
      shift
      ;;
    esac
  done
}

function abortUninstallation() {
  echo "WP Guardian agent uninstallation aborted."
  exit 1
}

function remove() {
  echo "Removing WP Guardian agent ..."
  if [ -e /etc/apt/sources.list.d/wp-agent.list ]; then
    if ! apt-get remove ${YES_FLAG} wp-agent; then
      abortUninstallation
    fi
    rm -f /etc/apt/sources.list.d/wp-agent.list
  elif  [ -e /etc/yum.repos.d/wp-agent.repo ]; then
    if ! yum remove ${YES_FLAG} wp-agent; then
      abortUninstallation
    fi
    rm -f /etc/yum.repos.d/wp-agent.repo
  fi
}

function removeInstallerLog() {
  rm -f ~/wp-agent-install.log
}

function removeAgentDir() {
  rm -rf /usr/local/wp-agent
}

parse_args "$@"
remove
removeInstallerLog
removeAgentDir





